pub fn cursor_v1() -> ProviderSchemaExpand description
Cursor IDE chat session schema.
Cursor stores sessions in a format similar to VS Code Copilot Chat JSON v3, but in Cursor’s own app data directory.
pub fn cursor_v1() -> ProviderSchemaCursor IDE chat session schema.
Cursor stores sessions in a format similar to VS Code Copilot Chat JSON v3, but in Cursor’s own app data directory.