close_vscode_and_wait

Function close_vscode_and_wait 

pub fn close_vscode_and_wait(timeout_secs: u64) -> Result<()>
Close VS Code gracefully and wait for it to exit. Returns the list of workspace folders that were open (for reopening).