pub fn parse_session_file(path: &Path) -> Result<ChatSession, Error>Expand description
Parse a session file, automatically detecting format from content (not just extension)
pub fn parse_session_file(path: &Path) -> Result<ChatSession, Error>Parse a session file, automatically detecting format from content (not just extension)